slicer\_package\_manager.models package
=======================================

.. automodule:: slicer_package_manager.models
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

slicer\_package\_manager.models.extension module
------------------------------------------------

.. automodule:: slicer_package_manager.models.extension
   :members:
   :undoc-members:
   :show-inheritance:

slicer\_package\_manager.models.package module
----------------------------------------------

.. automodule:: slicer_package_manager.models.package
   :members:
   :undoc-members:
   :show-inheritance:
